module.exports = function (grunt) {
  'use strict';

  grunt.loadNpmTasks('grunt-contrib-clean');
  grunt.loadNpmTasks('grunt-contrib-cssmin');
  grunt.loadNpmTasks('grunt-contrib-less');
  grunt.loadNpmTasks('grunt-contrib-watch');
  grunt.loadNpmTasks('grunt-newer');

  grunt.initConfig({

    clean: {
      css: [ 'dist/css' ]
    },

    less: {
      base: {
        options: {
          strictMath: true,
          sourceMap: true,
          outputSourceFiles: true,
          sourceMapURL: 'base.css.map',
          sourceMapFilename: 'dist/css/base.css.map'
        },
        src: 'dist/less/base.less',
        dest: 'dist/css/base.css'
      },
      screen: {
        options: {
          strictMath: true,
          sourceMap: true,
          outputSourceFiles: true,
          sourceMapURL: 'screen.css.map',
          sourceMapFilename: 'dist/css/screen.css.map'
        },
        src: 'dist/less/screen.less',
        dest: 'dist/css/screen.css'
      },
      print: {
        options: {
          strictMath: true,
          sourceMap: true,
          outputSourceFiles: true,
          sourceMapURL: 'print.css.map',
          sourceMapFilename: 'dist/css/print.css.map'
        },
        src: 'dist/less/print.less',
        dest: 'dist/css/print.css'
      },
      ie8: {
        options: {
          strictMath: true,
          sourceMap: true,
          outputSourceFiles: true,
          sourceMapURL: 'ie8.css.map',
          sourceMapFilename: 'dist/css/ie8.css.map'
        },
        src: 'dist/less/ie8.less',
        dest: 'dist/css/ie8.css'
      },
      tablet: {
        options: {
          strictMath: true,
          sourceMap: true,
          outputSourceFiles: true,
          sourceMapURL: 'tablet.css.map',
          sourceMapFilename: 'dist/css/tablet.css.map'
        },
        src: 'dist/less/tablet.less',
        dest: 'dist/css/tablet.css'
      },
      phone: {
        options: {
          strictMath: true,
          sourceMap: true,
          outputSourceFiles: true,
          sourceMapURL: 'phone.css.map',
          sourceMapFilename: 'dist/css/phone.css.map'
        },
        src: 'dist/less/phone.less',
        dest: 'dist/css/phone.css'
      },
      tiny: {
        options: {
          strictMath: true,
          sourceMap: true,
          outputSourceFiles: true,
          sourceMapURL: 'tiny.css.map',
          sourceMapFilename: 'dist/css/tiny.css.map'
        },
        src: 'dist/less/tiny.less',
        dest: 'dist/css/tiny.css'
      },
      seitenaufteilung: {
        options: {
          strictMath: true,
          sourceMap: true,
          outputSourceFiles: true,
          sourceMapURL: 'seitenaufteilung.css.map',
          sourceMapFilename: 'dist/css/seitenaufteilung.css.map'
        },
        src: 'dist/less/seitenaufteilung.less',
        dest: 'dist/css/seitenaufteilung.css'
      },
      seitenkopf: {
        options: {
          strictMath: true,
          sourceMap: true,
          outputSourceFiles: true,
          sourceMapURL: 'seitenkopf.css.map',
          sourceMapFilename: 'dist/css/seitenkopf.css.map'
        },
        src: 'dist/less/seitenkopf.less',
        dest: 'dist/css/seitenkopf.css'
      }
    },

    cssmin: {
      options: {
        compatibility: 'ie8',
        sourceMap: true,
        advanced: false
      },
      base: {
        src: 'dist/css/base.css',
        dest: 'dist/css/base.min.css'
      },
      screen: {
        src: 'dist/css/screen.css',
        dest: 'dist/css/screen.min.css'
      },
      print: {
        src: 'dist/css/print.css',
        dest: 'dist/css/print.min.css'
      },
      ie8: {
        src: 'dist/css/ie8.css',
        dest: 'dist/css/ie8.min.css'
      },
      tablet: {
        src: 'dist/css/tablet.css',
        dest: 'dist/css/tablet.min.css'
      },
      phone: {
        src: 'dist/css/phone.css',
        dest: 'dist/css/phone.min.css'
      },
      tiny: {
        src: 'dist/css/tiny.css',
        dest: 'dist/css/tiny.min.css'
      },
      seitenaufteilung: {
        src: 'dist/css/seitenaufteilung.css',
        dest: 'dist/css/seitenaufteilung.min.css'
      },
      seitenkopf: {
        src: 'dist/css/seitenkopf.css',
        dest: 'dist/css/seitenkopf.min.css'
      }
    },

    watch: {
      css: {
        files: [ 'dist/less/**/*.less' ],
        tasks: 'css'
      }
    }

  })


  // Task to build and minify the CSS
  grunt.registerTask('css', [ 'less', 'newer:cssmin' ]);

  // Task to build the distribution
  grunt.registerTask('dist', [ 'css' ]);


  // Task to start a local http-server for development
  grunt.registerTask('http-server', function() {

    grunt.util.spawn({
      cmd: 'node_modules/http-server/bin/http-server',
      args: [ 'dist', '-c60' ],
      opts: { stdio: 'inherit' }
    });

  });

  // Task to start development-environment
  grunt.registerTask('devel', [ 'dist', 'http-server', 'watch' ]);


  // Default task.
  grunt.registerTask('default', [ 'dist' ]);

}
